wagoe.geo.schema

Malli validation schemas for the geo module.

Malli validation schemas for the geo module.
raw docstring

AddressQueryclj

Address lookup query. At least one field should be provided. :country defaults to "Netherlands" when not supplied.

Address lookup query. At least one field should be provided.
:country defaults to "Netherlands" when not supplied.
sourceraw docstring

GeoConfigclj

Configuration map for the :wagoe/geo-service Integrant component.

Configuration map for the :wagoe/geo-service Integrant component.
sourceraw docstring

GeoPointclj

A geographic coordinate pair. :lat — latitude in decimal degrees (-90 to 90) :lng — longitude in decimal degrees (-180 to 180)

A geographic coordinate pair.
:lat — latitude  in decimal degrees (-90  to  90)
:lng — longitude in decimal degrees (-180 to 180)
sourceraw docstring

GeoResultclj

Result of a geocoding or reverse-geocoding operation. :provider — keyword identifying which provider returned the result :cached? — true if this result was served from the DB cache

Result of a geocoding or reverse-geocoding operation.
:provider — keyword identifying which provider returned the result
:cached?  — true if this result was served from the DB cache
sourceraw docstring

valid-address-query?clj

(valid-address-query? query)

Returns true if the given map satisfies AddressQuery schema.

Returns true if the given map satisfies AddressQuery schema.
sourceraw docstring

valid-geo-point?clj

(valid-geo-point? point)

Returns true if the given map satisfies GeoPoint schema.

Returns true if the given map satisfies GeoPoint schema.
sourceraw docstring

valid-geo-result?clj

(valid-geo-result? result)

Returns true if the given map satisfies GeoResult schema.

Returns true if the given map satisfies GeoResult schema.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries