Clojure only.

wagoe.geo.shell.cache

DB-backed geocoding cache implementing GeoCacheProtocol.

Uses a geo_cache table with a SHA-256 address hash as primary key. Run the migration in resources/wagoe/geo/migrations/001-geo-cache.sql before using this component.

TTL is enforced at lookup time by comparing created_at to NOW() - cache-ttl.

DB-backed geocoding cache implementing GeoCacheProtocol.

Uses a `geo_cache` table with a SHA-256 address hash as primary key.
Run the migration in resources/wagoe/geo/migrations/001-geo-cache.sql
before using this component.

TTL is enforced at lookup time by comparing `created_at` to `NOW() - cache-ttl`.
raw docstring

create-db-geo-cacheclj

(create-db-geo-cache ds)
(create-db-geo-cache ds cache-ttl)

Create a DB-backed geo cache.

Args: ds - next.jdbc datasource or connection pool cache-ttl - TTL in seconds (default: 86400 = 24 hours)

Returns: DbGeoCache implementing GeoCacheProtocol

Create a DB-backed geo cache.

Args:
  ds        - next.jdbc datasource or connection pool
  cache-ttl - TTL in seconds (default: 86400 = 24 hours)

Returns:
  DbGeoCache implementing GeoCacheProtocol
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries