Malli validation schemas for the geo module.
Malli validation schemas for the geo module.
Address lookup query. At least one field should be provided. :country defaults to "Netherlands" when not supplied.
Address lookup query. At least one field should be provided. :country defaults to "Netherlands" when not supplied.
Configuration map for the :wagoe/geo-service Integrant component.
Configuration map for the :wagoe/geo-service Integrant component.
A geographic coordinate pair. :lat — latitude in decimal degrees (-90 to 90) :lng — longitude in decimal degrees (-180 to 180)
A geographic coordinate pair. :lat — latitude in decimal degrees (-90 to 90) :lng — longitude in decimal degrees (-180 to 180)
Result of a geocoding or reverse-geocoding operation. :provider — keyword identifying which provider returned the result :cached? — true if this result was served from the DB cache
Result of a geocoding or reverse-geocoding operation. :provider — keyword identifying which provider returned the result :cached? — true if this result was served from the DB cache
(valid-address-query? query)Returns true if the given map satisfies AddressQuery schema.
Returns true if the given map satisfies AddressQuery schema.
(valid-geo-point? point)Returns true if the given map satisfies GeoPoint schema.
Returns true if the given map satisfies GeoPoint schema.
(valid-geo-result? result)Returns true if the given map satisfies GeoResult schema.
Returns true if the given map satisfies GeoResult schema.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |